Learn R Programming

EnvNJ (version 0.1.3)

ncdnj: Compute a Distance Matrix Using Normalized Compression Distance

Description

Computes a distance matrix using normalized compression distance.

Usage

ncdnj(wd)

Arguments

wd

character string indicating the path to the directory where the input files can be found (see details).

Value

A list where the first element is a symmetric distance matrix and the second one is a phylogenetic tree build using NJ.

Details

The input files, which must be found at the wd provided, consist of a file named 'list.txt' containing the names of the fasta files to be analyzed (one per line). The referred fasta files also must be found at the provided wd. This function use zpaq to compress files. Thus, the zpaq software must be installed on your system and in the search path for executables if you wish to use this function.

See Also

ncd()

Examples

Run this code
# NOT RUN {
try(ncdnj("./data_t"))
# }

Run the code above in your browser using DataLab