path to the working directory. This directory must contain a txt file per vector and an additional txt file named vlist.txt that provides the names (one per line) of the vector txt files.
metric
character string indicating the metric (see metrics() to see the methods allowed).
clustering
string indicating the clustering method, either "nj" or "upgma".
Value
a list with two elements: a distance matrix and a tree.
Details
This function computes the distance matrix and builds the corresponding tree.